@@ -13,6 +13,7 @@ class ConditionFHIR:
     default_coding_system = 'http://www.santepublique.rtss.qc.ca/sipmi/fa/1.0.0/vocabulary'
     default_coding_version = '1.0.0'
     agent_url = "http://www.santepublique.rtss.qc.ca/sipmi/fa/1.0.0/extensions/#condition/agent"
+    antigen_url = "http://www.santepublique.rtss.qc.ca/sipmi/fa/1.0.0/extensions/#condition/antigen"
 
     def __init__(self, resource=None) -> None:
         self.patient = None
@@ -57,20 +58,25 @@ class ConditionFHIR:
                 return coding
         return self.category['coding'][0]
 
-    def get_agent(self, system=None, version=None):
+    def get_extension(self, url, system=None, version=None):
         if system is None:
             system = self.default_coding_system
         if version is None:
             version = self.default_coding_version
 
         for extension in self.extension:
-            if 'url' in extension and extension['url'] == self.agent_url and "valueCodeableConcept" in extension:
+            if 'url' in extension and extension['url'] == url and "valueCodeableConcept" in extension:
                 for coding in extension['valueCodeableConcept']['coding']:
                     if coding['system'] == system and coding['version'] == version:
                         return coding
                 if len(extension['valueCodeableConcept']['coding']) > 0:     
                     return extension['valueCodeableConcept']['coding'][0]
 
+    def get_agent(self, system=None, version=None):
+        return self.get_extension(system=system, version=version, url=self.agent_url)
+
+    def get_antigen(self, system=None, version=None):
+        return self.get_extension(system=system, version=version, url=self.antigen_url)
 
 class OperationOutcomeFHIR:
     resource_type = "OperationOutcome"
